/* eslint-disable no-console */
import Axios from 'cheku-axios';
import { Toast } from 'vant';
import router from '@/router'
import store from '../store'
import Vue from 'vue'
var toastLoading;
Toast.allowMultiple();
var statusIndex  = 1;
Axios.defaults.timeout = 120000;
Axios.interceptors.request.use(config => {
  if(store.state.netStatus === 0){
    if(toastLoading){
      toastLoading.clear();
    }
    router.push({name:'network'});
  }
  return config;
}, error => Promise.reject(error))
Axios.interceptors.response.use((response) => {
  if(response.data.code !== 200){
      Toast({
          message: response.data.msg,
          icon: 'warn-o',
          duration:1000
      });
  }
  return response
}, (error) => {
  if(toastLoading){
    toastLoading.clear();
   }
  if(error.request && error.request.readyState == 4 && error.request.status == 0){
    Toast({
        message: localStorage.language && localStorage.language == 'en-US' ? 'The service has timed out. Please try again later...' : '服务超时，请稍后重试...',
        icon: 'warning',
        duration:2000
    });
  }else if(error.response && error.response.status == 401){
    if(statusIndex === 1){
        statusIndex = 2;
        localStorage.removeItem('token');
        localStorage.removeItem('userInfo');
        Toast(localStorage.language && localStorage.language == 'en-US' ? 'The login status has expired, please login again' : '登录状态已过期，请重新登录');
        setTimeout(() => {router.push({path:'/login'})},1000)
    }
  }else{
    Toast({
        message: localStorage.language && localStorage.language == 'en-US' ? 'System error. Please try again later...' :'系统错误，请稍后再试...',
        icon: 'warning',
        duration:1000
    });
  }
  return Promise.reject(error)
})

export const http = (config, token ,isLoading = true,text='') => {
  if(token){
    if(!localStorage.token){
      Toast({
          message: localStorage.language && localStorage.language == 'en-US' ? 'You are not logged in yet and are about to log in' : '您尚未登录，即将前去登录',
          icon: 'warning',
          duration:1000
      });
      setTimeout(() => {
          router.push({name:'login'})
      },1000) 
      return;
    }
  }
  if(isLoading){
    toastLoading = Toast.loading({
      duration: 0,       // 持续展示 toast
      forbidClick: true, // 禁用背景点击
      loadingType: 'spinner',
      message: localStorage.language && localStorage.language == 'en-US' ? 'loading...' : `加载中...`
  });
  }
  
  if (Object.prototype.toString.call(config) === '[object Array]') { // 接口并发问题
    const CONFIG = config.map((m) => {
      return Axios({
        method: m.method,
        url: m.url,
        headers: m.headers,
        data: m.data,
        params: m.params
      })
    })
    return Axios.all(CONFIG).then(Axios.spread((...argument) => {
      if(isLoading){
        toastLoading.clear();
      }
      const result = [...argument].map((m) => {
        return m.data
      })
      if(result.every(m => {return m.code == 401})){
        Toast({
            message: localStorage.language && localStorage.language == 'en-US' ? 'The login status has expired, please login again' : '登录状态已过期，请重新登录',
            icon: 'warn-o',
            duration:1000
        });
        localStorage.removeItem('token');
        localStorage.removeItem('userInfo');
        setTimeout(() => {
            router.push({name:'login'})
        },1000)
      }else if(result.every(m => {return m.code == 403})){
        Toast({
            message: localStorage.language && localStorage.language == 'en-US' ? 'Insufficient permissions, please contact the administrator' : '权限不足，请联系管理员',
            icon: 'warn-o',
            duration:1000
        });
      }
      return result
    }))
  } else {
    if(isLoading){
      toastLoading.clear();
    }
    return Axios(config)
  }
}

export const httpHD = (config, token) => {
  if(token){
    if(!localStorage.token){
      Toast({
          message: localStorage.language && localStorage.language == 'en-US' ? 'You are not logged in yet and are about to log in' : '您尚未登录，即将前去登录',
          icon: 'warning',
          duration:1000
      });
      setTimeout(() => {
          router.push({name:'login'})
      },1000) 
      return;
    }
  }
  if (Object.prototype.toString.call(config) === '[object Array]') { // 接口并发问题
    const CONFIG = config.map((m) => {
      return Axios({
        method: m.method,
        url: m.url,
        headers: m.headers,
        data: m.data,
        params: m.params
      })
    })
    return Axios.all(CONFIG).then(Axios.spread((...argument) => {
      const result = [...argument].map((m) => {
        return m.data
      })
      if(result.every(m => {return m.code == 401})){
        Toast({
            message: localStorage.language && localStorage.language == 'en-US' ? 'The login status has expired, please login again' : '登录状态已过期，请重新登录',
            icon: 'warn-o',
            duration:1000
        });
        localStorage.removeItem('token');
        localStorage.removeItem('userInfo');
        setTimeout(() => {
            router.push({name:'login'})
        },1000)
      }else if(result.every(m => {return m.code == 403})){
        Toast({
            message: localStorage.language && localStorage.language == 'en-US' ? 'Insufficient permissions, please contact the administrator' : '权限不足，请联系管理员',
            icon: 'warn-o',
            duration:1000
        });
      }
      return result
    }))
  } else {
    return Axios(config)
  }
}
